# eric7.EricXML.SessionReader

Module implementing a class for reading an XML session file.

### Global Attributes

None

### Classes

SessionReader | Class for reading an XML session file.

### Functions

None

## SessionReader

Class for reading an XML session file.

### Derived from

XMLStreamReaderBase

### Class Attributes

supportedVersions

### Class Methods

None

### Methods

SessionReader | Constructor
__readBookmark | Private method to read the bookmark info.
__readBookmarks | Private method to read the bookmark infos.
__readBreakpoint | Private method to read the break point info.
__readBreakpoints | Private method to read the break point infos.
__readDebugInfo | Private method to read the debug infos.
__readFilenames | Private method to read the file name infos.
__readProjectBrowserState | Private method to read the project browser state info.
__readProjectBrowserStates | Private method to read the project browser state infos.
__readWatchexpression | Private method to read the watch expression info.
__readWatchexpressions | Private method to read watch expression infos.
readXML | Public method to read and parse the XML document.

### Static Methods

None

#### SessionReader (Constructor)

SessionReader(device, isGlobal)

Constructor

device (QIODevice)
  reference to the I/O device to read from
isGlobal (bool)
  flag indicating to read the global session

#### SessionReader.__readBookmark

__readBookmark()

Private method to read the bookmark info.

#### SessionReader.__readBookmarks

__readBookmarks()

Private method to read the bookmark infos.

#### SessionReader.__readBreakpoint

__readBreakpoint()

Private method to read the break point info.

#### SessionReader.__readBreakpoints

__readBreakpoints()

Private method to read the break point infos.

#### SessionReader.__readDebugInfo

__readDebugInfo()

Private method to read the debug infos.

#### SessionReader.__readFilenames

__readFilenames()

Private method to read the file name infos.

#### SessionReader.__readProjectBrowserState

__readProjectBrowserState(browserName)

Private method to read the project browser state info.

browserName (str)
  name of the project browser

#### SessionReader.__readProjectBrowserStates

__readProjectBrowserStates()

Private method to read the project browser state infos.

#### SessionReader.__readWatchexpression

__readWatchexpression()

Private method to read the watch expression info.

#### SessionReader.__readWatchexpressions

__readWatchexpressions()

Private method to read watch expression infos.

#### SessionReader.readXML

readXML(quiet=False)

Public method to read and parse the XML document.

quiet (bool)
  flag indicating quiet operations. If this flag is true, no errors are reported.

Up